@@ -38,7 +38,7 @@
  *
  * Since: 1.0.0
  */
-#define GGANDIVA_VERSION_MAJOR (21)
+#define GGANDIVA_VERSION_MAJOR (23)
 
 /**
  * GGANDIVA_VERSION_MINOR:
@@ -110,6 +110,24 @@
 #  define GGANDIVA_UNAVAILABLE(major, minor) G_UNAVAILABLE(major, minor)
 #endif
 
+/**
+ * GGANDIVA_VERSION_23_0:
+ *
+ * You can use this macro value for compile time API version check.
+ *
+ * Since: 23.0.0
+ */
+#define GGANDIVA_VERSION_23_0 G_ENCODE_VERSION(23, 0)
+
+/**
+ * GGANDIVA_VERSION_22_0:
+ *
+ * You can use this macro value for compile time API version check.
+ *
+ * Since: 22.0.0
+ */
+#define GGANDIVA_VERSION_22_0 G_ENCODE_VERSION(22, 0)
+
 /**
  * GGANDIVA_VERSION_21_0:
  *
@@ -433,6 +451,34 @@
 
 #define GGANDIVA_AVAILABLE_IN_ALL GGANDIVA_EXTERN
 
+#if GGANDIVA_VERSION_MIN_REQUIRED >= GGANDIVA_VERSION_23_0
+#  define GGANDIVA_DEPRECATED_IN_23_0               GGANDIVA_DEPRECATED
+#  define GGANDIVA_DEPRECATED_IN_23_0_FOR(function) GGANDIVA_DEPRECATED_FOR(function)
+#else
+#  define GGANDIVA_DEPRECATED_IN_23_0
+#  define GGANDIVA_DEPRECATED_IN_23_0_FOR(function)
+#endif
+
+#if GGANDIVA_VERSION_MAX_ALLOWED < GGANDIVA_VERSION_23_0
+#  define GGANDIVA_AVAILABLE_IN_23_0 GGANDIVA_EXTERN GGANDIVA_UNAVAILABLE(23, 0)
+#else
+#  define GGANDIVA_AVAILABLE_IN_23_0 GGANDIVA_EXTERN
+#endif
+
+#if GGANDIVA_VERSION_MIN_REQUIRED >= GGANDIVA_VERSION_22_0
+#  define GGANDIVA_DEPRECATED_IN_22_0               GGANDIVA_DEPRECATED
+#  define GGANDIVA_DEPRECATED_IN_22_0_FOR(function) GGANDIVA_DEPRECATED_FOR(function)
+#else
+#  define GGANDIVA_DEPRECATED_IN_22_0
+#  define GGANDIVA_DEPRECATED_IN_22_0_FOR(function)
+#endif
+
+#if GGANDIVA_VERSION_MAX_ALLOWED < GGANDIVA_VERSION_22_0
+#  define GGANDIVA_AVAILABLE_IN_22_0 GGANDIVA_EXTERN GGANDIVA_UNAVAILABLE(22, 0)
+#else
+#  define GGANDIVA_AVAILABLE_IN_22_0 GGANDIVA_EXTERN
+#endif
+
 #if GGANDIVA_VERSION_MIN_REQUIRED >= GGANDIVA_VERSION_21_0
 #  define GGANDIVA_DEPRECATED_IN_21_0               GGANDIVA_DEPRECATED
 #  define GGANDIVA_DEPRECATED_IN_21_0_FOR(function) GGANDIVA_DEPRECATED_FOR(function)
